{"": "", "Add": "", "Add new device": "", "Cancel": "Cancelar", "Device": "", "Device:": "", "FS Type": "", "Frequency:": "", "Modify": "", "Mounted": "", "Mountpoint": "", "Mountpoint:": "", "Options:": "Opciones:", "Pass:": "", "Save": "", "Size": "", "Type": "", "Type:": "", "Usage": "", "Used": "", "Fstab": "", "Device successfully unmounted!": "", "Fstab successfully saved!": "", "Do you really want to permanently delete this entry?": "", "Delete": ""}