{"": "", "Add": "Ajouter", "Add new device": "Ajouter un nouveau p\u00e9riph\u00e9rique", "Cancel": "Annuler", "Device": "P\u00e9riph\u00e9rique", "Device:": "P\u00e9riph\u00e9rique:", "FS Type": "Type de syst\u00e8mes de fichiers", "Frequency:": "Fr\u00e9quence:", "Modify": "Modifier", "Mounted": "Mont\u00e9s", "Mountpoint": "Point de montage", "Mountpoint:": "Point de montage:", "Options:": "Options :", "Pass:": "Passage :", "Save": "Sauvegarder", "Size": "Taille", "Type": "Type", "Type:": "Type:", "Usage": "Utilisation", "Used": "Utilis\u00e9", "Fstab": "Fstab", "Device successfully unmounted!": "P\u00e9riph\u00e9rique d\u00e9mont\u00e9 avec succ\u00e8s !", "Fstab successfully saved!": "Fstab enregistr\u00e9 avec succ\u00e8s !", "Do you really want to permanently delete this entry?": "Souhaitez-vous vraiment supprimer cette entr\u00e9e\u00a0?", "Delete": "Supprimer"}