{"": "", "Add": "Neu", "Add new device": "Neues Ger\u00e4t hinzuf\u00fcgen", "Cancel": "Abbrechen", "Device": "Ger\u00e4t", "Device:": "Ger\u00e4t:", "FS Type": "FS Typ", "Frequency:": "H\u00e4ufigkeit:", "Modify": "\u00c4ndern", "Mounted": "Eingeh\u00e4ngt", "Mountpoint": "Mountpoint", "Mountpoint:": "Mountpoint:", "Options:": "Optionen:", "Pass:": "Durchlauf:", "Save": "Speichern", "Size": "Gr\u00f6\u00dfe", "Type": "Typ", "Type:": "Typ:", "Usage": "Nutzung", "Used": "Verwendet", "Fstab": "Fstab", "Device successfully unmounted!": "Ger\u00e4t erfolgreich ausgeh\u00e4ngt!", "Fstab successfully saved!": "Fstab erfolgreich gespeichert!", "Do you really want to permanently delete this entry?": "Wollen Sie diesen Eintrag wirklich entfernen?", "Delete": "Entfernen"}