{"": "", "Add": "Aggiungi", "Add new device": "Aggiungi nuovo dispositivo", "Cancel": "Annulla", "Device": "Dispositivo", "Device:": "Dispositivo:", "FS Type": "Tipo di FS", "Frequency:": "Frequenza:", "Modify": "Modifica", "Mounted": "Montato", "Mountpoint": "Punto di montaggio", "Mountpoint:": "Punto di montaggio:", "Options:": "Opzioni:", "Pass:": "Riuscito:", "Save": "Salva", "Size": "Dimensione", "Type": "Tipo", "Type:": "Tipo:", "Usage": "Uso", "Used": "Usato", "Fstab": "Fstab", "Device successfully unmounted!": "Dispositivo smontato correttamente!", "Fstab successfully saved!": "Fstab salvata correttamente!", "Do you really want to permanently delete this entry?": "Sei sicuro di voler eliminare permanentemente questa voce?", "Delete": "Elimina"}