{"": "", "Add": "Ekle", "Add new device": "Yeni bir cihaz ekle", "Cancel": "Vazge\u00e7", "Device": "Ayg\u0131t", "Device:": "Ayg\u0131t", "FS Type": "", "Frequency:": "S\u0131kl\u0131k", "Modify": "D\u00fczenle", "Mounted": "Ba\u011fland\u0131", "Mountpoint": "Ba\u011flama Noktas\u0131", "Mountpoint:": "Ba\u011flama Noktas\u0131:", "Options:": "Se\u00e7enekler:", "Pass:": "Ge\u00e7:", "Save": "Kaydet", "Size": "Boyut", "Type": "T\u00fcr", "Type:": "T\u00fcr:", "Usage": "Kullan\u0131m", "Used": "Kullan\u0131lan", "Fstab": "Fstab", "Device successfully unmounted!": "Ayg\u0131t ba\u015far\u0131yla ayr\u0131ld\u0131!", "Fstab successfully saved!": "Fstab ba\u015far\u0131yla kaydedildi!", "Do you really want to permanently delete this entry?": "Bu girdiyi kal\u0131c\u0131 olarak silmek istiyor musun?", "Delete": "Sil"}