{"": "", "Add": "Adicionar", "Add new device": "Adicionar novo dispositivo", "Cancel": "Cancelar", "Device": "Dispositivo", "Device:": "Dispositivo:", "FS Type": "", "Frequency:": "Frequ\u00eancia:", "Modify": "Modificar", "Mounted": "Montado", "Mountpoint": "Ponto de montagem", "Mountpoint:": "Ponto de montagem:", "Options:": "Op\u00e7\u00f5es:", "Pass:": "Senha:", "Save": "Salvar", "Size": "Tamanho", "Type": "Tipo", "Type:": "Tipo:", "Usage": "Uso", "Used": "Usado", "Fstab": "Fstab", "Device successfully unmounted!": "Dispositivo desmontado com sucesso!", "Fstab successfully saved!": "Fstab salvo com sucesso!", "Do you really want to permanently delete this entry?": "Voc\u00ea realmente quer excluir esta entrada permanentemente?", "Delete": "Excluir"}