{"": "", "Add": "L\u00e4gg till", "Add new device": "L\u00e4gg till ny enhet", "Cancel": "Avbryt", "Device": "Enhet", "Device:": "Enhet:", "FS Type": "", "Frequency:": "Frekvens", "Modify": "\u00c4ndra", "Mounted": "Monterad", "Mountpoint": "Monteringspunkt", "Mountpoint:": "Monteringspunkt:", "Options:": "Alternativ:", "Pass:": "Pass:", "Save": "Spara", "Size": "Storlek", "Type": "Typ", "Type:": "Typ:", "Usage": "Anv\u00e4ndning", "Used": "Anv\u00e4nds", "Fstab": "Fstab", "Device successfully unmounted!": "Enheten har avmonterats!", "Fstab successfully saved!": "Fstab har sparats!", "Do you really want to permanently delete this entry?": "Vill du verkligen permanent ta bort denna post?", "Delete": "Radera"}