{"": "", "Add": "Dodaj", "Add new device": "Dodaj nowe urz\u0105dzenie", "Cancel": "Anuluj", "Device": "Urz\u0105dzenie", "Device:": "Urz\u0105dzenie:", "FS Type": "", "Frequency:": "Cz\u0119stotliwo\u015b\u0107:", "Modify": "Modyfikuj", "Mounted": "Zamontowane", "Mountpoint": "Punkt montowania", "Mountpoint:": "Punkt montowania:", "Options:": "Opcje:", "Pass:": "Has\u0142o:", "Save": "Zapisz", "Size": "Rozmiar", "Type": "Typ", "Type:": "Typ:", "Usage": "U\u017cycie", "Used": "U\u017cywane", "Fstab": "Fstab", "Device successfully unmounted!": "Urz\u0105dzenie zosta\u0142o roz\u0142\u0105czone!", "Fstab successfully saved!": "Fstab zosta\u0142 pomy\u015blnie zapisany!", "Do you really want to permanently delete this entry?": "Czy naprawd\u0119 chcesz trwale usun\u0105\u0107 ten wpis?", "Delete": "Usu\u0144"}